package de.uni_marburg.powersort.benchmark;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;
import java.util.function.Supplier;

public class Main {
    public static void main(final String[] args) throws InvocationTargetException, IllegalAccessException, NoSuchMethodException {
        final Method[] sortImplementations = getSortImplementations();
        final List<Supplier<Object[]>> sortInputSuppliers = getSortInputSuppliers();

        final NaturalOrder c = NaturalOrder.INSTANCE;
        for (Supplier<Object[]> sortInputSupplier : sortInputSuppliers) {
            for (Method sortImplementation : sortImplementations) {
                Object[] sortInput = sortInputSupplier.get();
                sortImplementation.invoke(null, sortInput, 0, 0, c, null, 0, 0);
                System.out.println(Arrays.toString(sortInput));
            }
        }
    }

    static Method[] getSortImplementations() throws NoSuchMethodException {
        return new Method[]{
                DummySort.class.getMethod("sort", Object[].class, int.class, int.class, Comparator.class, Object[].class, int.class, int.class),
                DummySort2.class.getMethod("sort", Object[].class, int.class, int.class, Comparator.class, Object[].class, int.class, int.class)
        };
    }

    static List<Supplier<Object[]>> getSortInputSuppliers() {
        return Arrays.asList(
                () -> new DummyComparable2[]{new DummyComparable2(0), new DummyComparable2(1)},
                () -> new DummyComparable2[]{new DummyComparable2(2), new DummyComparable2(3)}
        );
    }
}
